import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { scaleOrdinal } from 'd3-scale';
import { schemeSet1 } from 'd3-scale-chromatic';
import { produce } from 'immer';
import { useMemo, useReducer } from 'react';
import MarkerDefs from './components/Annotations/MarkerDefs';
import Tracking from './components/Tracking';
import TransparentRect from './components/TransparentRect';
import { LegendProvider } from './components/legendsContext';
import { PlotContext, DispatchContext, useAxisContext } from './hooks';
import { reducer } from './plotReducer';
import { splitChildren } from './utils';
const reducerCurr = produce(reducer);
const initialState = {
    series: [],
    axis: {},
};
const defaultSvgStyle = {
    fontFamily: 'Arial, Helvetica, sans-serif',
};
/**
 * Static plot with fixed dimension.
 */
export default function Plot(props) {
    const { width, height, colorScheme = schemeSet1, margin = {}, svgStyle = {}, svgId, svgClassName, plotViewportStyle = {}, seriesViewportStyle = {}, onClick, onMouseMove, onMouseEnter, onMouseLeave, children, } = props;
    const [state, dispatch] = useReducer(reducerCurr, initialState, undefined);
    const { seriesAndAnnotations, axes, heading, legend } = splitChildren(children);
    if ([width, height].includes(undefined)) {
        throw new Error('Width and height are mandatory');
    }
    // Distances in plot
    const { left = 0, right = 0, top = 0, bottom = 0 } = margin;
    const plotWidth = width - left - right;
    const plotHeight = height - top - bottom;
    // Set scales
    const axisContext = useAxisContext(state, { plotWidth, plotHeight });
    const labels = useMemo(() => state.series.map(({ id, label }) => ({ id, label })), [state.series]);
    const ids = useMemo(() => state.series.map(({ id }) => id), [state.series]);
    const colorScaler = useMemo(() => {
        return scaleOrdinal().range(colorScheme).domain(ids);
    }, [colorScheme, ids]);
    return (_jsx(PlotContext.Provider, Object.assign({ value: {
            width,
            height,
            left,
            right,
            top,
            bottom,
            plotWidth,
            plotHeight,
            labels,
            colorScaler,
            axisContext,
        } }, { children: _jsx(DispatchContext.Provider, Object.assign({ value: { dispatch } }, { children: _jsx(LegendProvider, { children: _jsxs("svg", Object.assign({ xmlns: "http://www.w3.org/2000/svg", width: width, height: height, style: { ...defaultSvgStyle, ...svgStyle }, id: svgId, className: svgClassName }, { children: [_jsx(MarkerDefs, {}, void 0), _jsx(TransparentRect, { width: width, height: height, style: plotViewportStyle }, void 0), _jsxs("g", Object.assign({ transform: `translate(${left}, ${top})` }, { children: [_jsx(TransparentRect, { width: plotWidth, height: plotHeight, style: seriesViewportStyle }, void 0), _jsx("clipPath", Object.assign({ id: "seriesViewportClip" }, { children: _jsx("rect", { width: plotWidth, height: plotHeight }, void 0) }), void 0), _jsx("g", Object.assign({ style: { clipPath: 'url(#seriesViewportClip)' } }, { children: seriesAndAnnotations }), void 0), axes, onClick || onMouseMove ? (_jsx(Tracking, { stateSeries: state.series, onClick: (position) => onClick === null || onClick === void 0 ? void 0 : onClick(position), onMouseMove: (position) => onMouseMove === null || onMouseMove === void 0 ? void 0 : onMouseMove(position), onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave }, void 0)) : null] }), void 0), heading, legend] }), void 0) }, void 0) }), void 0) }), void 0));
}
//# sourceMappingURL=Plot.js.map