import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo } from 'react';
import { usePlotContext } from '../hooks';
import { validateAxis, validateSeriesPointError } from '../utils';
export default function ErrorBars(props) {
    const { xAxis = 'x', yAxis = 'y', data, hidden, ...otherProps } = props;
    const { axisContext } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, xAxis, yAxis);
    const points = useMemo(() => {
        if (hidden)
            return null;
        if ([xScale, yScale].includes(undefined))
            return null;
        const pointBars = data.map((point, i) => {
            const xError = validateSeriesPointError(point.xError);
            const yError = validateSeriesPointError(point.yError);
            return (_jsx(PointBars // eslint-disable-next-line react/no-array-index-key
            , Object.assign({ origin: { x: xScale(point.x), y: yScale(point.y) }, bottom: yError ? yScale(point.y - yError[0]) : null, top: yError ? yScale(point.y + yError[1]) : null, left: xError ? xScale(point.x - xError[0]) : null, right: xError ? xScale(point.x + xError[1]) : null }, otherProps), `ErrorBars-${i}`));
        });
        return pointBars;
    }, [data, xScale, yScale, hidden, otherProps]);
    return _jsx("g", { children: points }, void 0);
}
function PointBars(props) {
    const { origin, top, bottom, left, right, style, capSize = 10, capStyle, } = props;
    const defaultColor = 'black';
    return (_jsxs("g", { children: [top != null && (_jsxs("g", { children: [_jsx("line", Object.assign({ x1: origin.x, x2: origin.x, y1: origin.y, y2: top, stroke: defaultColor }, style), void 0), _jsx("line", Object.assign({ x1: origin.x - capSize / 2, x2: origin.x + capSize / 2, y1: top, y2: top, stroke: defaultColor }, style, capStyle), void 0)] }, void 0)), bottom != null && (_jsxs("g", { children: [_jsx("line", Object.assign({ x1: origin.x, x2: origin.x, y1: origin.y, y2: bottom, stroke: defaultColor }, style), void 0), _jsx("line", Object.assign({ x1: origin.x - capSize / 2, x2: origin.x + capSize / 2, y1: bottom, y2: bottom, stroke: defaultColor }, style, capStyle), void 0)] }, void 0)), left != null && (_jsxs("g", { children: [_jsx("line", Object.assign({ x1: origin.x, x2: left, y1: origin.y, y2: origin.y, stroke: defaultColor }, style), void 0), _jsx("line", Object.assign({ x1: left, x2: left, y1: origin.y - capSize / 2, y2: origin.y + capSize / 2, stroke: defaultColor }, style, capStyle), void 0)] }, void 0)), right != null && (_jsxs("g", { children: [_jsx("line", Object.assign({ x1: origin.x, x2: right, y1: origin.y, y2: origin.y, stroke: defaultColor }, style), void 0), _jsx("line", Object.assign({ x1: right, x2: right, y1: origin.y - capSize / 2, y2: origin.y + capSize / 2, stroke: defaultColor }, style, capStyle), void 0)] }, void 0))] }, void 0));
}
//# sourceMappingURL=ErrorBars.js.map