"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_scale_1 = require("d3-scale");
const d3_scale_chromatic_1 = require("d3-scale-chromatic");
const immer_1 = require("immer");
const react_1 = require("react");
const MarkerDefs_1 = __importDefault(require("./components/Annotations/MarkerDefs"));
const Tracking_1 = __importDefault(require("./components/Tracking"));
const TransparentRect_1 = __importDefault(require("./components/TransparentRect"));
const legendsContext_1 = require("./components/legendsContext");
const hooks_1 = require("./hooks");
const plotReducer_1 = require("./plotReducer");
const utils_1 = require("./utils");
const reducerCurr = (0, immer_1.produce)(plotReducer_1.reducer);
const initialState = {
    series: [],
    axis: {},
};
const defaultSvgStyle = {
    fontFamily: 'Arial, Helvetica, sans-serif',
};
/**
 * Static plot with fixed dimension.
 */
function Plot(props) {
    const { width, height, colorScheme = d3_scale_chromatic_1.schemeSet1, margin = {}, svgStyle = {}, svgId, svgClassName, plotViewportStyle = {}, seriesViewportStyle = {}, onClick, onMouseMove, onMouseEnter, onMouseLeave, children, } = props;
    const [state, dispatch] = (0, react_1.useReducer)(reducerCurr, initialState, undefined);
    const { seriesAndAnnotations, axes, heading, legend } = (0, utils_1.splitChildren)(children);
    if ([width, height].includes(undefined)) {
        throw new Error('Width and height are mandatory');
    }
    // Distances in plot
    const { left = 0, right = 0, top = 0, bottom = 0 } = margin;
    const plotWidth = width - left - right;
    const plotHeight = height - top - bottom;
    // Set scales
    const axisContext = (0, hooks_1.useAxisContext)(state, { plotWidth, plotHeight });
    const labels = (0, react_1.useMemo)(() => state.series.map(({ id, label }) => ({ id, label })), [state.series]);
    const ids = (0, react_1.useMemo)(() => state.series.map(({ id }) => id), [state.series]);
    const colorScaler = (0, react_1.useMemo)(() => {
        return (0, d3_scale_1.scaleOrdinal)().range(colorScheme).domain(ids);
    }, [colorScheme, ids]);
    return ((0, jsx_runtime_1.jsx)(hooks_1.PlotContext.Provider, Object.assign({ value: {
            width,
            height,
            left,
            right,
            top,
            bottom,
            plotWidth,
            plotHeight,
            labels,
            colorScaler,
            axisContext,
        } }, { children: (0, jsx_runtime_1.jsx)(hooks_1.DispatchContext.Provider, Object.assign({ value: { dispatch } }, { children: (0, jsx_runtime_1.jsx)(legendsContext_1.LegendProvider, { children: (0, jsx_runtime_1.jsxs)("svg", Object.assign({ xmlns: "http://www.w3.org/2000/svg", width: width, height: height, style: { ...defaultSvgStyle, ...svgStyle }, id: svgId, className: svgClassName }, { children: [(0, jsx_runtime_1.jsx)(MarkerDefs_1.default, {}, void 0), (0, jsx_runtime_1.jsx)(TransparentRect_1.default, { width: width, height: height, style: plotViewportStyle }, void 0), (0, jsx_runtime_1.jsxs)("g", Object.assign({ transform: `translate(${left}, ${top})` }, { children: [(0, jsx_runtime_1.jsx)(TransparentRect_1.default, { width: plotWidth, height: plotHeight, style: seriesViewportStyle }, void 0), (0, jsx_runtime_1.jsx)("clipPath", Object.assign({ id: "seriesViewportClip" }, { children: (0, jsx_runtime_1.jsx)("rect", { width: plotWidth, height: plotHeight }, void 0) }), void 0), (0, jsx_runtime_1.jsx)("g", Object.assign({ style: { clipPath: 'url(#seriesViewportClip)' } }, { children: seriesAndAnnotations }), void 0), axes, onClick || onMouseMove ? ((0, jsx_runtime_1.jsx)(Tracking_1.default, { stateSeries: state.series, onClick: (position) => onClick === null || onClick === void 0 ? void 0 : onClick(position), onMouseMove: (position) => onMouseMove === null || onMouseMove === void 0 ? void 0 : onMouseMove(position), onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave }, void 0)) : null] }), void 0), heading, legend] }), void 0) }, void 0) }), void 0) }), void 0));
}
exports.default = Plot;
