"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
/* eslint-disable react/no-array-index-key */
const Plot_1 = __importDefault(require("./Plot"));
const Annotation_1 = require("./components/Annotations/Annotation");
const Axis_1 = __importDefault(require("./components/Axis"));
const ParallelAxis_1 = __importDefault(require("./components/Axis/ParallelAxis"));
const Legend_1 = __importDefault(require("./components/Legend"));
const LineSeries_1 = __importDefault(require("./components/LineSeries"));
const ScatterSeries_1 = __importDefault(require("./components/ScatterSeries"));
function PlotObject({ plot: { dimensions, svg = {}, seriesViewportStyle, axes, content, legend, colorScheme, }, children, }) {
    const { className: svgClassName, id: svgId, style: svgStyle, ...svgProps } = svg;
    return ((0, jsx_runtime_1.jsxs)(Plot_1.default, Object.assign({ colorScheme: colorScheme, seriesViewportStyle: seriesViewportStyle }, dimensions, { svgClassName: svgClassName, svgId: svgId, svgStyle: svgStyle }, svgProps, { children: [axes.map((axisProps) => {
                switch (axisProps.type) {
                    case 'main': {
                        const { type, ...props } = axisProps;
                        return (0, jsx_runtime_1.jsx)(Axis_1.default, Object.assign({}, props), axisProps.position);
                    }
                    case 'secondary': {
                        const { type, ...props } = axisProps;
                        return (0, jsx_runtime_1.jsx)(ParallelAxis_1.default, Object.assign({}, props), `secondary-${props.id}`);
                    }
                    default: {
                        return null;
                    }
                }
            }), legend !== undefined ? (0, jsx_runtime_1.jsx)(Legend_1.default, Object.assign({}, legend), void 0) : null, content.map((contentProps, i) => {
                switch (contentProps.type) {
                    case 'line': {
                        const { type, ...props } = contentProps;
                        return (0, jsx_runtime_1.jsx)(LineSeries_1.default, Object.assign({}, props), `${type}-${i}`);
                    }
                    case 'scatter': {
                        const { type, ...props } = contentProps;
                        return (0, jsx_runtime_1.jsx)(ScatterSeries_1.default, Object.assign({}, props), `${type}-${i}`);
                    }
                    case 'annotation': {
                        return ((0, jsx_runtime_1.jsx)(Annotation_1.Annotations, { children: contentProps.children.map(annotationMap) }, `${contentProps.type}-${i}`));
                    }
                    default: {
                        return null;
                    }
                }
            }), children && (0, jsx_runtime_1.jsx)(Annotation_1.Annotations, { children: children }, void 0)] }), void 0));
}
exports.default = PlotObject;
function annotationMap(annotationProps, index) {
    switch (annotationProps.type) {
        case 'arrow': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Arrow, Object.assign({}, props), `${type}-${index}`);
        }
        case 'circle': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Circle, Object.assign({}, props), `${type}-${index}`);
        }
        case 'ellipse': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Ellipse, Object.assign({}, props), `${type}-${index}`);
        }
        case 'line': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Line, Object.assign({}, props), `${type}-${index}`);
        }
        case 'rectangle': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Rectangle, Object.assign({}, props), `${type}-${index}`);
        }
        case 'shape': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Shape, Object.assign({}, props), `${type}-${index}`);
        }
        case 'text': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Text, Object.assign({}, props), `${type}-${index}`);
        }
        case 'group': {
            const { type, children, ...props } = annotationProps;
            return ((0, jsx_runtime_1.jsx)(Annotation_1.Group, Object.assign({}, props, { children: children.map(annotationMap) }), `${type}-${index}`));
        }
        default: {
            return null;
        }
    }
}
