"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_scale_1 = require("d3-scale");
const react_1 = require("react");
const react_d3_utils_1 = require("react-d3-utils");
const hooks_1 = require("../../hooks");
const VerticalText_1 = __importDefault(require("../VerticalText"));
const TicksLog_1 = require("./TicksLog");
function LeftLogAxis({ id, displayGridLines, hidden = false, label, labelSpace, labelStyle, fontSize, tickStyle, hiddenTicks = false, tickEmbedded, tickLength, hiddenSecondaryTicks, }) {
    const { axisContext, plotHeight, plotWidth } = (0, hooks_1.usePlotContext)();
    // Calculates the main axis values
    const { scale = (0, d3_scale_1.scaleLog)(), scientific } = axisContext[id] || {};
    const groupRef = (0, react_1.useRef)(null);
    const tickFormat = (0, react_1.useMemo)(() => (scientific ? (x) => x.toExponential(2) : undefined), [scientific]);
    const ticks = (0, react_d3_utils_1.useLogTicks)(scale, 'vertical', groupRef, {
        tickFormat,
    });
    const range = (scale === null || scale === void 0 ? void 0 : scale.range()) || [0, 0];
    // Create gridlines
    const gridlines = (0, react_1.useMemo)(() => {
        if (!displayGridLines || !scale)
            return null;
        return ((0, jsx_runtime_1.jsx)("g", Object.assign({ className: "gridLines" }, { children: ticks.map(({ position }) => ((0, jsx_runtime_1.jsx)("line", { x1: "0", x2: plotWidth, y1: position, y2: position, stroke: "black", strokeDasharray: "2,2", strokeOpacity: 0.5 }, position))) }), void 0));
    }, [displayGridLines, ticks, scale, plotWidth]);
    const tickDirection = tickEmbedded ? 1 : -1;
    const tickLen = tickDirection * tickLength;
    const tickTextPosition = tickEmbedded ? -8 : -8 + tickLen;
    return ((0, jsx_runtime_1.jsxs)("g", Object.assign({ className: "axis" }, { children: [gridlines, !hidden && ((0, jsx_runtime_1.jsxs)("g", Object.assign({ ref: groupRef, className: "ticks" }, { children: [(0, jsx_runtime_1.jsx)("line", { y1: range[0], y2: range[1], stroke: "black" }, void 0), (0, jsx_runtime_1.jsx)(TicksLog_1.TicksLog, { hidden: hiddenTicks, ticks: ticks, style: tickStyle, hiddenSecondaryTicks: hiddenSecondaryTicks, getPositions: (y) => ({
                            line: { x2: tickLen, y1: y, y2: y },
                            text: { x1: tickTextPosition, y1: y },
                        }) }, void 0)] }), void 0)), label && !hidden && ((0, jsx_runtime_1.jsx)(VerticalText_1.default, { label: label, transform: `translate(${0 - fontSize - labelSpace - (scientific ? 14 : 0)}, ${plotHeight / 2})`, dy: fontSize, fontSize: fontSize, style: labelStyle }, void 0))] }), void 0));
}
exports.default = LeftLogAxis;
