"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const hooks_1 = require("../../hooks");
const BottomAxis_1 = __importDefault(require("./BottomAxis"));
const BottomLogAxis_1 = __importDefault(require("./BottomLogAxis"));
const LeftAxis_1 = __importDefault(require("./LeftAxis"));
const LeftLogAxis_1 = __importDefault(require("./LeftLogAxis"));
const RightAxis_1 = __importDefault(require("./RightAxis"));
const RightLogAxis_1 = __importDefault(require("./RightLogAxis"));
const TopAxis_1 = __importDefault(require("./TopAxis"));
const TopLogAxis_1 = __importDefault(require("./TopLogAxis"));
function parallelPosition(position) {
    switch (position) {
        case 'bottom': {
            return 'top';
        }
        case 'top': {
            return 'bottom';
        }
        case 'left': {
            return 'right';
        }
        case 'right': {
            return 'left';
        }
        default: {
            throw new Error(`Unknown position ${position}`);
        }
    }
}
function ParallelAxis({ id, fontSize = 16, labelSpace = 24, hidden = false, tickStyle = {}, tickLength = 6, ...props }) {
    const { axisContext } = (0, hooks_1.usePlotContext)();
    // Don't display axis if parent id not in context
    const parentAxis = axisContext[id];
    if (!parentAxis)
        return null;
    // Get position oposite to parent axis
    const position = parallelPosition(parentAxis.position);
    const existing = Object.values(axisContext).find((axis) => axis.position === position);
    if (existing)
        throw new Error(`Position ${position} was already declared`);
    // Renders accordly to position and scale
    const { type } = parentAxis;
    const childProps = {
        id,
        fontSize,
        labelSpace,
        hidden,
        tickStyle,
        tickLength,
        ...props,
    };
    switch (`${position}-${type}`) {
        case 'top-log':
            return (0, jsx_runtime_1.jsx)(TopLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'top-linear':
            return (0, jsx_runtime_1.jsx)(TopAxis_1.default, Object.assign({}, childProps), void 0);
        case 'bottom-log':
            return (0, jsx_runtime_1.jsx)(BottomLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'bottom-linear':
            return (0, jsx_runtime_1.jsx)(BottomAxis_1.default, Object.assign({}, childProps), void 0);
        case 'left-log':
            return (0, jsx_runtime_1.jsx)(LeftLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'left-linear':
            return (0, jsx_runtime_1.jsx)(LeftAxis_1.default, Object.assign({}, childProps), void 0);
        case 'right-log':
            return (0, jsx_runtime_1.jsx)(RightLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'right-linear':
            return (0, jsx_runtime_1.jsx)(RightAxis_1.default, Object.assign({}, childProps), void 0);
        default:
            return null;
    }
}
exports.default = ParallelAxis;
