"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_scale_1 = require("d3-scale");
const react_1 = require("react");
const react_d3_utils_1 = require("react-d3-utils");
const hooks_1 = require("../../hooks");
const TicksLog_1 = require("./TicksLog");
function TopLogAxis({ id, displayGridLines, hidden = false, label, labelSpace, labelStyle, fontSize, tickStyle, hiddenTicks = false, tickEmbedded, tickLength, hiddenSecondaryTicks, }) {
    const { axisContext, plotWidth, plotHeight } = (0, hooks_1.usePlotContext)();
    // Calculates the main axis values
    const { scale = (0, d3_scale_1.scaleLog)(), scientific } = axisContext[id] || {};
    const groupRef = (0, react_1.useRef)(null);
    const tickFormat = (0, react_1.useMemo)(() => (scientific ? (x) => x.toExponential(2) : undefined), [scientific]);
    const ticks = (0, react_d3_utils_1.useLogTicks)(scale, 'vertical', groupRef, {
        tickFormat,
    });
    const range = (scale === null || scale === void 0 ? void 0 : scale.range()) || [0, 0];
    // Create gridlines
    const gridlines = (0, react_1.useMemo)(() => {
        if (!displayGridLines || !scale)
            return null;
        return ((0, jsx_runtime_1.jsx)("g", Object.assign({ className: "gridLines" }, { children: ticks.map(({ position }) => ((0, jsx_runtime_1.jsx)("line", { x1: position, x2: position, y1: plotHeight, y2: "0", stroke: "black", strokeDasharray: "2,2", strokeOpacity: 0.5 }, position))) }), void 0));
    }, [displayGridLines, ticks, scale, plotHeight]);
    const tickDirection = tickEmbedded ? 1 : -1;
    const tickLen = tickDirection * tickLength;
    const tickTextPosition = tickEmbedded ? -12 : -12 + tickLen;
    return ((0, jsx_runtime_1.jsxs)("g", Object.assign({ className: "axis" }, { children: [gridlines, !hidden && ((0, jsx_runtime_1.jsxs)("g", Object.assign({ className: "ticks" }, { children: [(0, jsx_runtime_1.jsx)("line", { x1: range[0], x2: range[1], stroke: "black" }, void 0), (0, jsx_runtime_1.jsx)(TicksLog_1.TicksLog, { anchor: "middle", hidden: hiddenTicks, ticks: ticks, style: tickStyle, hiddenSecondaryTicks: hiddenSecondaryTicks, getPositions: (val) => ({
                            line: { x1: val, x2: val, y2: tickLen },
                            text: { x1: val, y1: tickTextPosition },
                        }) }, void 0)] }), void 0)), label && !hidden && ((0, jsx_runtime_1.jsx)("text", Object.assign({ x: plotWidth / 2, y: 0 - labelSpace - fontSize, fontSize: fontSize, textAnchor: "middle", style: labelStyle }, { children: label }), void 0))] }), void 0));
}
exports.default = TopLogAxis;
