"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.exclusiveProps = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
/* eslint-disable react/no-array-index-key */
const react_1 = require("react");
const react_d3_utils_1 = require("react-d3-utils");
const hooks_1 = require("../hooks");
const Markers_1 = require("./Markers");
const legendsContext_1 = require("./legendsContext");
function exclusiveProps(margins, a, b, position) {
    if (margins[a] !== undefined) {
        if (margins[b] !== undefined) {
            throw new Error(`${a} and ${b} should't be both defined for the position ${position}`);
        }
        return { key: a, value: margins[a] };
    }
    return margins[b] !== undefined ? { key: b, value: margins[b] } : {};
}
exports.exclusiveProps = exclusiveProps;
function translation(position, legendMargins, plotMargins, width, height) {
    const plotHeight = height - plotMargins.top - plotMargins.bottom;
    const plotWidth = width - plotMargins.left - plotMargins.right;
    switch (position) {
        case 'embedded': {
            const { key: verticalKey = 'top', value: verticalValue = 10, } = exclusiveProps(legendMargins, 'top', 'bottom', position);
            const { key: horizontalKey = 'left', value: horizontalValue = 10, } = exclusiveProps(legendMargins, 'left', 'right', position);
            const x = horizontalKey === 'right'
                ? width - plotMargins.right - horizontalValue
                : plotMargins.left + horizontalValue;
            const y = verticalKey === 'bottom'
                ? height - plotMargins.bottom - verticalValue
                : plotMargins.top + verticalValue;
            return {
                x,
                y,
                horizontalAlign: horizontalKey === 'left' ? 'start' : 'end',
                verticalAlign: verticalKey === 'top' ? 'start' : 'end',
            };
        }
        case 'top': {
            const { key: horizontalKey = 'left', value: horizontalValue = plotWidth / 2, } = exclusiveProps(legendMargins, 'left', 'right', position);
            const x = horizontalKey === 'right'
                ? width - plotMargins.right + horizontalValue
                : plotMargins.left + horizontalValue;
            const y = plotMargins.top - (legendMargins.bottom || 50);
            return { x, y };
        }
        case 'bottom': {
            const { key: horizontalKey = 'left', value: horizontalValue = plotWidth / 2, } = exclusiveProps(legendMargins, 'left', 'right', position);
            const x = horizontalKey === 'right'
                ? width - plotMargins.right + horizontalValue
                : plotMargins.left + horizontalValue;
            const y = height - plotMargins.bottom + (legendMargins.top || 25);
            return { x, y };
        }
        case 'left': {
            const { key: verticalKey = 'top', value: verticalValue = plotHeight / 2, } = exclusiveProps(legendMargins, 'top', 'bottom', position);
            const y = verticalKey === 'bottom'
                ? height - plotMargins.bottom - verticalValue
                : plotMargins.top + verticalValue;
            const x = plotMargins.left - (legendMargins.right || 100);
            return { x, y };
        }
        case 'right': {
            const { key: verticalKey = 'top', value: verticalValue = plotHeight / 2, } = exclusiveProps(legendMargins, 'top', 'bottom', position);
            const y = verticalKey === 'bottom'
                ? height - plotMargins.bottom - verticalValue
                : plotMargins.top + verticalValue;
            const x = width - plotMargins.right + (legendMargins.left || 40);
            return { x, y };
        }
        default: {
            throw new Error(`Position ${JSON.stringify(position)} unknown`);
        }
    }
}
function Legend({ position, ...legendMargins }) {
    const { right, left, top, bottom, height, width } = (0, hooks_1.usePlotContext)();
    const [state] = (0, legendsContext_1.useLegend)();
    const alignGroupProps = (0, react_1.useMemo)(() => {
        const plotMargins = { right, left, top, bottom };
        return translation(position, legendMargins, plotMargins, width, height);
    }, [position, legendMargins, right, left, top, bottom, width, height]);
    return ((0, jsx_runtime_1.jsx)(react_d3_utils_1.AlignGroup, Object.assign({}, alignGroupProps, { children: state.labels.map((value, index) => {
            const xPos = 10;
            const yPos = (index + 1) * 16 - xPos + 5;
            if (value.range) {
                return ((0, jsx_runtime_1.jsxs)("g", Object.assign({ transform: `translate(${xPos}, ${0})` }, { children: [getRangeShape({
                            index,
                            rangeColor: value.range.rangeColor,
                            lineColor: value.colorLine,
                        }), (0, jsx_runtime_1.jsx)("text", Object.assign({ x: 30, y: `${index + 1}em` }, { children: value.label }), `text-${value.label}-${index}`)] }), `${value.colorLine}/${value.range.rangeColor}-${value.label}`));
            }
            const Marker = Markers_1.markersComps[value.shape.figure];
            return ((0, jsx_runtime_1.jsxs)("g", Object.assign({ transform: `translate(${xPos}, ${0})` }, { children: [getLineShape({ index, color: value.colorLine }), (0, jsx_runtime_1.jsx)("g", Object.assign({ transform: `translate(${xPos - 1}, ${yPos})` }, { children: !value.shape.hidden && ((0, jsx_runtime_1.jsx)(Marker, { size: 10, style: { fill: value.shape.color } }, void 0)) }), void 0), (0, jsx_runtime_1.jsx)("text", Object.assign({ x: 30, y: `${index + 1}em` }, { children: value.label }), `text-${value.label}-${index}`)] }), `${value.colorLine}/${value.shape.color}-${value.label}`));
        }) }), void 0));
}
exports.default = Legend;
function getLineShape(config) {
    const x = 0;
    const y = (config.index + 1) * 16 - x - 7;
    return (0, jsx_runtime_1.jsx)("rect", { x: x, y: y, width: "20", height: "3", fill: config.color }, void 0);
}
function getRangeShape(config) {
    const x = 0;
    const y = (config.index + 1) * 16 - x - 12;
    return ((0, jsx_runtime_1.jsxs)("g", Object.assign({ transform: `translate(${x}, ${y})` }, { children: [(0, jsx_runtime_1.jsx)("rect", { width: "20", height: "10", fill: config.rangeColor }, void 0), (0, jsx_runtime_1.jsx)("line", { x1: 0, y: 0, x2: 20, y2: 0, stroke: config.lineColor, strokeWidth: 3 }, void 0), (0, jsx_runtime_1.jsx)("line", { x1: 0, y1: 10, x2: 20, y2: 10, stroke: config.lineColor, strokeWidth: 3 }, void 0)] }), void 0));
}
