"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hexagon = exports.Star = exports.Pentagon = exports.XMark = exports.Cross = exports.Triangle = exports.Diamond = exports.Square = exports.Circle = exports.markersComps = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
exports.markersComps = {
    circle: Circle,
    square: Square,
    diamond: Diamond,
    triangle: Triangle,
    cross: Cross,
    xmark: XMark,
    pentagon: Pentagon,
    star: Star,
    hexagon: Hexagon,
};
const halfPi = Math.PI / 2;
const twoPi = Math.PI * 2;
function Circle({ style, size }) {
    return (0, jsx_runtime_1.jsx)("circle", { r: size / 2, style: style }, void 0);
}
exports.Circle = Circle;
function Square({ style, size }) {
    const x = size / 2;
    return (0, jsx_runtime_1.jsx)("rect", { x: -x, y: -x, width: size, height: size, style: style }, void 0);
}
exports.Square = Square;
function Diamond({ size, style }) {
    const x = size / 2;
    return (0, jsx_runtime_1.jsx)("polygon", { points: `0,${-x} ${x},0 0,${x} ${-x},0`, style: style }, void 0);
}
exports.Diamond = Diamond;
function Triangle({ style, size }) {
    const height = (Math.sqrt(3) * size) / 2;
    const x = size / 2;
    return ((0, jsx_runtime_1.jsx)("polygon", { transform: `translate(0, -${(size - height) / 2})`, points: `${-x},${x} ${x},${x} 0,${x - height}`, style: style }, void 0));
}
exports.Triangle = Triangle;
function Cross({ size, style }) {
    const x = size / 2;
    return ((0, jsx_runtime_1.jsxs)("g", Object.assign({ strokeWidth: 1, style: style }, { children: [(0, jsx_runtime_1.jsx)("line", { x1: 0, x2: 0, y1: x, y2: -x }, void 0), (0, jsx_runtime_1.jsx)("line", { x1: -x, x2: x, y1: 0, y2: 0 }, void 0)] }), void 0));
}
exports.Cross = Cross;
function XMark(props) {
    return ((0, jsx_runtime_1.jsx)("g", Object.assign({ transform: "rotate(45)" }, { children: (0, jsx_runtime_1.jsx)(Cross, Object.assign({}, props), void 0) }), void 0));
}
exports.XMark = XMark;
function Pentagon({ style, size }) {
    return ((0, jsx_runtime_1.jsx)("polygon", { points: Array.from(getPolyPoints(size, 5)).join(' '), style: style }, void 0));
}
exports.Pentagon = Pentagon;
function Star({ style, size }) {
    const ext = Array.from(getPolyPoints(size, 5, 0));
    const int = Array.from(getPolyPoints(size / 2.5, 5, (2 * Math.PI) / 10));
    const points = [];
    for (let i = 0; i < ext.length; i++) {
        points.push(ext[i], int[i]);
    }
    return (0, jsx_runtime_1.jsx)("polygon", { points: points.join(' '), style: style }, void 0);
}
exports.Star = Star;
function Hexagon({ style, size }) {
    return ((0, jsx_runtime_1.jsx)("polygon", { points: Array.from(getPolyPoints(size, 6)).join(' '), style: style }, void 0));
}
exports.Hexagon = Hexagon;
/**
 * https://math.stackexchange.com/a/3582355
 */
function* getPolyPoints(diameter, k, angle = 0) {
    const r = diameter / 2;
    for (let i = 0; i < k; i++) {
        const calculation = (twoPi * i) / k - halfPi + angle;
        const x = r * Math.cos(calculation);
        const y = r * Math.sin(calculation);
        yield `${x},${y}`;
    }
}
