"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_array_1 = require("d3-array");
const d3_shape_1 = require("d3-shape");
const react_1 = require("react");
const hooks_1 = require("../hooks");
const utils_1 = require("../utils");
const legendsContext_1 = require("./legendsContext");
function RangeSeries(props) {
    const [id] = (0, react_1.useState)(() => props.groupId || `series-${(0, utils_1.getNextId)()}`);
    const [, legendDispatch] = (0, legendsContext_1.useLegend)();
    const { lineStyle = {}, hidden, xAxis, yAxis, data, label } = props;
    // Update plot context with data description
    const { dispatch } = (0, hooks_1.useDispatchContext)();
    (0, react_1.useEffect)(() => {
        const [xMin, xMax] = (0, d3_array_1.extent)(data, (d) => d.x);
        const [y1Min, y1Max] = (0, d3_array_1.extent)(data, (d) => d.y1);
        const [y2Min, y2Max] = (0, d3_array_1.extent)(data, (d) => d.y2);
        const x = { min: xMin, max: xMax, axisId: xAxis };
        const y = {
            min: Math.min(y1Min, y2Min),
            max: Math.max(y1Max, y2Max),
            axisId: yAxis,
        };
        dispatch({ type: 'newData', value: { id, x, y, label } });
        // Delete information on unmount
        return () => dispatch({ type: 'removeData', value: { id } });
    }, [dispatch, id, data, xAxis, yAxis, label]);
    (0, react_1.useEffect)(() => {
        legendDispatch({
            type: 'ADD_LEGEND_LABEL',
            payload: {
                id,
                label,
                colorLine: lineStyle.stroke,
                range: {
                    rangeColor: lineStyle.fill,
                },
            },
        });
        return () => legendDispatch({
            type: 'REMOVE_LEGEND_LABEL',
            payload: { id },
        });
    }, [label, legendDispatch, lineStyle.fill, lineStyle.stroke, id]);
    if (hidden)
        return null;
    const lineProps = {
        id,
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        lineStyle,
    };
    return (0, jsx_runtime_1.jsx)(RangeSeriesRender, Object.assign({}, lineProps), void 0);
}
exports.default = RangeSeries;
function RangeSeriesRender({ data, xAxis, yAxis, lineStyle, }) {
    // Get scales from context
    const { axisContext } = (0, hooks_1.usePlotContext)();
    const [xScale, yScale] = (0, utils_1.validateAxis)(axisContext, xAxis, yAxis);
    // calculates the path to display
    const path = (0, react_1.useMemo)(() => {
        if ([xScale, yScale].includes(undefined))
            return null;
        // Calculate area from D3
        const areaGenerator = (0, d3_shape_1.area)()
            .x((d) => xScale(d.x))
            .y0((d) => yScale(d.y1))
            .y1((d) => yScale(d.y2));
        return areaGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        strokeWidth: 2,
        ...lineStyle,
    };
    return (0, jsx_runtime_1.jsx)("path", { style: style, d: path, fill: "none" }, void 0);
}
