"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_array_1 = require("d3-array");
const react_1 = require("react");
const hooks_1 = require("../hooks");
const utils_1 = require("../utils");
const ErrorBars_1 = __importDefault(require("./ErrorBars"));
const Markers_1 = require("./Markers");
const legendsContext_1 = require("./legendsContext");
function ScatterSeries(props) {
    var _a;
    // Update plot context with data description
    const { dispatch } = (0, hooks_1.useDispatchContext)();
    const { colorScaler } = (0, hooks_1.usePlotContext)();
    const [, legendDispatch] = (0, legendsContext_1.useLegend)();
    const [id] = (0, react_1.useState)(() => props.groupId || `series-${(0, utils_1.getNextId)()}`);
    const { xAxis = 'x', yAxis = 'y', data, label, hidden, displayErrorBars = false, ...otherProps } = props;
    (0, react_1.useEffect)(() => {
        var _a;
        if (!hidden) {
            legendDispatch({
                type: 'ADD_LEGEND_LABEL',
                payload: {
                    id,
                    label,
                    colorLine: 'white',
                    shape: {
                        color: ((_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill.toString()) || colorScaler(id),
                        figure: 'circle',
                        hidden: false,
                    },
                },
            });
        }
        return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
    }, [
        colorScaler,
        hidden,
        id,
        label,
        legendDispatch,
        otherProps.markerShape,
        (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill,
    ]);
    (0, react_1.useEffect)(() => {
        const [xMin, xMax] = (0, d3_array_1.extent)(data, (d) => d.x);
        const [yMin, yMax] = (0, d3_array_1.extent)(data, (d) => d.y);
        const x = { min: xMin, max: xMax, axisId: xAxis };
        const y = { min: yMin, max: yMax, axisId: yAxis };
        dispatch({ type: 'newData', value: { id, x, y, label, data } });
        // Delete information on unmount
        return () => dispatch({ type: 'removeData', value: { id } });
    }, [dispatch, id, data, xAxis, yAxis, label]);
    if (hidden)
        return null;
    // Render stateless plot component
    const inheritedProps = { data, xAxis, yAxis };
    const errorBarsProps = {
        hidden: !displayErrorBars,
        style: props.errorBarsStyle,
        capStyle: props.errorBarsCapStyle,
        capSize: props.errorBarsCapSize,
    };
    return ((0, jsx_runtime_1.jsxs)("g", { children: [(0, jsx_runtime_1.jsx)(ErrorBars_1.default, Object.assign({}, inheritedProps, errorBarsProps), void 0), (0, jsx_runtime_1.jsx)(ScatterSeriesRender, Object.assign({}, otherProps, inheritedProps, { id: id }), void 0)] }, void 0));
}
exports.default = ScatterSeries;
function ScatterSeriesRender({ id, data, xAxis, yAxis, markerShape = 'circle', markerSize = 8, markerStyle = {}, }) {
    // Get scales from context
    const { axisContext, colorScaler } = (0, hooks_1.usePlotContext)();
    const [xScale, yScale] = (0, utils_1.validateAxis)(axisContext, xAxis, yAxis);
    // calculates the path to display
    const markers = (0, react_1.useMemo)(() => {
        if ([xScale, yScale].includes(undefined))
            return null;
        const color = colorScaler(id);
        const defaultColor = { fill: color, stroke: color };
        // Show markers
        const Marker = Markers_1.markersComps[markerShape];
        const markers = data.map((point, i) => {
            const style = (0, utils_1.functionalStyle)(defaultColor, markerStyle, point, i, data);
            return ((0, jsx_runtime_1.jsx)("g", Object.assign({ transform: `translate(${xScale(point.x)}, ${yScale(point.y)})` }, { children: (0, jsx_runtime_1.jsx)(Marker, { size: markerSize, style: { stroke: style.fill, ...style } }, void 0) }), `markers-${i}`));
        });
        return markers;
    }, [
        xScale,
        yScale,
        colorScaler,
        id,
        data,
        markerSize,
        markerStyle,
        markerShape,
    ]);
    if (!markers)
        return null;
    return (0, jsx_runtime_1.jsx)("g", Object.assign({ className: "markers" }, { children: markers }), void 0);
}
